@@ -6,6 +6,7 @@ import base64
 from .. import error
 from .. import encoding
 from .. import constants
+from .algod import _specify_round_string
 
 api_version_path_prefix = "/v2"
 
@@ -62,7 +63,7 @@ class IndexerClient:
             requrl = api_version_path_prefix + requrl
         if params:
             requrl = requrl + "?" + parse.urlencode(params)
-        
+
         req = Request(self.indexer_address+requrl, headers=header, method=method,
                       data=data)
 
@@ -74,7 +75,12 @@ class IndexerClient:
                 raise error.IndexerHTTPError(json.loads(e)["message"])
             except:
                 raise error.IndexerHTTPError(e)
-        return json.loads(resp.read().decode("utf-8"))
+        response_dict = json.loads(resp.read().decode("utf-8"))
+
+        def recursively_sort_dict(dictionary):
+            return {k: recursively_sort_dict(v) if isinstance(v, dict) else v
+                    for k, v in sorted(dictionary.items())}
+        return recursively_sort_dict(response_dict)
 
     def health(self, **kwargs):
         """Return 200 and a simple status message if the node is running."""
@@ -83,7 +89,8 @@ class IndexerClient:
 
     def accounts(
         self, asset_id=None, limit=None, next_page=None, min_balance=None,
-        max_balance=None, block=None, auth_addr=None, application_id=None, **kwargs):
+        max_balance=None, block=None, auth_addr=None, application_id=None,
+        round_num=None, **kwargs):
         """
         Return accounts that match the search; microalgos are the default
         currency unless asset_id is specified, in which case the asset will
@@ -102,8 +109,10 @@ class IndexerClient:
                 some configurations
             auth_addr (str, optional): Include accounts configured to use
                 this spending key.
-            application_id (int, optional): results should filter on this application
-
+            application_id (int, optional): results should filter on this
+                application
+            round_num (int, optional): alias for block; only specify one of
+                these
         """
         req = "/accounts"
         query = dict()
@@ -117,16 +126,15 @@ class IndexerClient:
             query["currency-greater-than"] = min_balance
         if max_balance:
             query["currency-less-than"] = max_balance
-        if block:
-            query["round"] = block
+        _specify_round(query, block, round_num)
         if auth_addr:
             query["auth-addr"] = auth_addr
         if application_id:
             query["application-id"] = application_id
         return self.indexer_request("GET", req, query, **kwargs)
-    
+
     def asset_balances(self, asset_id, limit=None, next_page=None, min_balance=None,
-        max_balance=None, block=None, **kwargs):
+        max_balance=None, block=None, round_num=None, **kwargs):
         """
         Return accounts that hold the asset; microalgos are the default
         currency unless asset_id is specified, in which case the asset will
@@ -143,6 +151,8 @@ class IndexerClient:
             block (int, optional): include results for the specified round;
                 for performance reasons, this parameter may be disabled on
                 some configurations
+            round_num (int, optional): alias for block; only specify one of
+                these
         """
         req = "/assets/" + str(asset_id) + "/balances"
         query = dict()
@@ -154,32 +164,38 @@ class IndexerClient:
             query["currency-greater-than"] = min_balance
         if max_balance:
             query["currency-less-than"] = max_balance
-        if block:
-            query["round"] = block
+        _specify_round(query, block, round_num)
         return self.indexer_request("GET", req, query, **kwargs)
 
-    def block_info(self, block, **kwargs):
+    def block_info(self, block=None, round_num=None, **kwargs):
         """
         Get the block for the given round.
 
         Args:
-            block (int): block number
+            block (int, optional): block number
+            round_num (int, optional): alias for block; specify one of these
         """
-        req = "/blocks/" + str(block)
+        req = "/blocks/"
+        if block is None and round_num is None:
+            raise error.UnderspecifiedRoundError
+        req = "/blocks/" + _specify_round_string(block, round_num)
+
         return self.indexer_request("GET", req, **kwargs)
 
-    def account_info(self, address, block=None, **kwargs):
+    def account_info(self, address, block=None, round_num=None, **kwargs):
         """
         Return account information.
 
         Args:
             address (str): account public key
             block (int, optional): use results from the specified round
+            round_num (int, optional): alias for block; only specify one of
+                these
         """
         req = "/accounts/" + address
         query = dict()
-        if block:
-            query["round"] = block
+        _specify_round(query, block, round_num)
+
         return self.indexer_request("GET", req, query, **kwargs)
 
     def search_transactions(
@@ -187,7 +203,8 @@ class IndexerClient:
         sig_type=None, txid=None, block=None, min_round=None, max_round=None,
         asset_id=None, start_time=None, end_time=None, min_amount=None,
         max_amount=None, address=None, address_role=None,
-        exclude_close_to=False, application_id=None, rekey_to=False, **kwargs):
+        exclude_close_to=False, application_id=None, rekey_to=False,
+        round_num=None, **kwargs):
         """
         Return a list of transactions satisfying the conditions.
 
@@ -231,8 +248,10 @@ class IndexerClient:
                 to true
             application_id (int, optional): filter for transactions pertaining
                 to an application
-            rekey_to (bool, optional) Include results which include the
-                rekey-to field.
+            rekey_to (bool, optional): include results which include the
+                rekey-to field
+            round_num (int, optional): alias for block; only specify one of
+                these
         """
         req = "/transactions"
         query = dict()
@@ -248,8 +267,7 @@ class IndexerClient:
             query["sig-type"] = sig_type
         if txid:
             query["txid"] = txid
-        if block:
-            query["round"] = block
+        _specify_round(query, block, round_num)
         if min_round:
             query["min-round"] = min_round
         if max_round:
@@ -275,14 +293,14 @@ class IndexerClient:
         if rekey_to:
             query["rekey-to"] = "true"
 
-
         return self.indexer_request("GET", req, query, **kwargs)
 
     def search_transactions_by_address(
         self, address, limit=None, next_page=None, note_prefix=None,
         txn_type=None, sig_type=None, txid=None, block=None, min_round=None,
         max_round=None, asset_id=None, start_time=None, end_time=None,
-        min_amount=None, max_amount=None, rekey_to=False, **kwargs):
+        min_amount=None, max_amount=None, rekey_to=False, round_num=None,
+        **kwargs):
         """
         Return a list of transactions satisfying the conditions for the address.
 
@@ -316,8 +334,10 @@ class IndexerClient:
             max_amount (int, optional): results should have an amount less
                 than this value, microalgos are the default currency unless an
                 asset-id is provided, in which case the asset will be used
-            rekey_to (bool, optional) Include results which include the
-                rekey-to field.
+            rekey_to (bool, optional): include results which include the
+                rekey-to field
+            round_num (int, optional): alias for block; only specify one of
+                these
         """
         req = "/accounts/" + address + "/transactions"
         query = dict()
@@ -333,8 +353,7 @@ class IndexerClient:
             query["sig-type"] = sig_type
         if txid:
             query["txid"] = txid
-        if block:
-            query["round"] = block
+        _specify_round(query, block, round_num)
         if min_round:
             query["min-round"] = min_round
         if max_round:
@@ -358,14 +377,13 @@ class IndexerClient:
         txn_type=None, sig_type=None, txid=None, block=None, min_round=None,
         max_round=None, address=None, start_time=None, end_time=None,
         min_amount=None, max_amount=None, address_role=None,
-        exclude_close_to=False, rekey_to=False, **kwargs):
+        exclude_close_to=False, rekey_to=False, round_num=None, **kwargs):
         """
         Return a list of transactions satisfying the conditions for the address.
 
         Args:
             asset_id (int): include transactions for the specified
                 asset
-                
             limit (int, optional): maximum number of results to return
             next_page (str, optional): the next page of results; use the next
                 token provided by the previous results
@@ -401,8 +419,10 @@ class IndexerClient:
                 search for; the close to fields are normally treated as a
                 receiver, if you would like to exclude them set this parameter
                 to true
-            rekey_to (bool, optional) Include results which include the
-                rekey-to field.
+            rekey_to (bool, optional): include results which include the
+                rekey-to field
+            round_num (int, optional): alias for block; only specify one of
+                these
         """
         req = "/assets/" + str(asset_id) + "/transactions"
         query = dict()
@@ -418,8 +438,7 @@ class IndexerClient:
             query["sig-type"] = sig_type
         if txid:
             query["txid"] = txid
-        if block:
-            query["round"] = block
+        _specify_round(query, block, round_num)
         if min_round:
             query["min-round"] = min_round
         if max_round:
@@ -442,7 +461,7 @@ class IndexerClient:
             query["rekey-to"] = "true"
 
         return self.indexer_request("GET", req, query, **kwargs)
-    
+
     def search_assets(
         self, limit=None, next_page=None, creator=None, name=None, unit=None,
         asset_id=None, **kwargs):
@@ -473,7 +492,7 @@ class IndexerClient:
             query["unit"] = unit
         if asset_id:
             query["asset-id"] = asset_id
-        
+
         return self.indexer_request("GET", req, query, **kwargs)
 
     def asset_info(self, asset_id, **kwargs):
@@ -487,41 +506,64 @@ class IndexerClient:
         return self.indexer_request("GET", req, **kwargs)
 
     def applications(
-            self, application_id, round=None, **kwargs):
+            self, application_id, round=None, round_num=None, **kwargs):
         """
         Return applications that satisfy the conditions.
 
         Args:
             application_id (int): application index
-            round (int, optional): restrict search to passed round
+            round (int, optional): restrict search to passed round;
+                deprecated, please use round_num
+            round_num (int, optional): alias for round; only specify one of these
         """
         req = "/applications/" + str(application_id)
         query = dict()
-        if round:
-            query["round"] = round
+        _specify_round(query, round, round_num)
 
         return self.indexer_request("GET", req, query, **kwargs)
 
     def search_applications(
-            self, application_id=None, round=None, limit=None, next_page=None, **kwargs):
+            self, application_id=None, round=None, limit=None, next_page=None,
+            round_num=None, **kwargs):
         """
         Return applications that satisfy the conditions.
 
         Args:
             application_id (int, optional): restrict search to application index
             round (int, optional): restrict search to passed round
+                deprecated, please use round_num
             limit (int, optional): restrict number of results to limit
             next_page (string, optional): used for pagination
+            round_num (int, optional): alias for round; only specify one of these
         """
         req = "/applications"
         query = dict()
         if application_id:
             query["application-id"] = application_id
-        if round:
-            query["round"] = round
+        _specify_round(query, round, round_num)
         if limit:
             query["limit"] = limit
         if next_page:
             query["next"] = next_page
 
         return self.indexer_request("GET", req, query, **kwargs)
+
+    
+def _specify_round(query, block, round_num):
+    """
+    Set the round number in the query dictionary from either 'block' or
+    'round_num'.
+
+    Args:
+        query (dict): dictionary in which to set round
+        block (int): user specified variable
+        round_num (int): user specified variable
+    """
+
+    if block is not None and round_num is not None:
+        raise error.OverspecifiedRoundError
+    elif block is not None:
+        if block:
+            query["round"] = block
+    elif round_num:
+        query["round"] = round_num
